@@ -1,7 +1,9 @@
 # coding=utf-8
 #
 # catkin_lint
-# Copyright (c) 2013-2020 Fraunhofer FKIE
+# Copyright 2013-2022 Fraunhofer FKIE
+#
+# SPDX-License-Identifier: BSD-3-Clause
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -12,7 +14,7 @@
 #  * Redistributions in binary form must reproduce the above copyright
 #    notice, this list of conditions and the following disclaimer in the
 #    documentation and/or other materials provided with the distribution.
-#  * Neither the name of the Fraunhofer organization nor the names of its
+#  * Neither the name of the copyright holder nor the names of its
 #    contributors may be used to endorse or promote products derived from
 #    this software without specific prior written permission.
 #
@@ -46,12 +48,7 @@ class Rosdep(object):
         self.quiet = quiet
 
     def is_ros(self, name):
-        try:
-            if self.view is not None:
-                return self.view.lookup(name).data["_is_ros"]
-        except KeyError:
-            pass
-        return False
+        return self.view.lookup(name).data.get("_is_ros", False) if self.view is not None else False
 
     def has_key(self, name):
         return self.view is not None and name in self.view.keys()
@@ -62,7 +59,7 @@ def get_rosdep(quiet):
     from rosdep2.rospkg_loader import DEFAULT_VIEW_KEY
     from rosdep2.sources_list import SourcesListLoader
     dummy = DummyRospkg()
-    sources_loader = SourcesListLoader.create_default()
+    sources_loader = SourcesListLoader.create_default(sources_cache_dir=os.environ.get("ROSDEP_CACHE_PATH", None))
     lookup = RosdepLookup.create_from_rospkg(rospack=dummy, rosstack=dummy, sources_loader=sources_loader)
     return Rosdep(view=lookup.get_rosdep_view(DEFAULT_VIEW_KEY), quiet=quiet)
 
